---
name: "\U0001F41E Issues, bugs and problems"
about: Contribute a report and describe what should have happened.
title: ''
labels: ''
assignees: ''

---

<!-- Thank you for taking the time to create this report. Your feedback is appreciated ! -->

## What component is this about ?
<!-- The API or the API clients ? The Ansible roles or plugins ? Something else ? -->
<!-- For ara-web issues, please use https://github.com/ansible-community/ara-web/issues -->


## What is your ARA installation like ?
<!-- What version of Ansible and ARA ? Did you install from source or from PyPi ? With an Ansible role ? In a virtualenv or a container ? Which Linux distribution ? Which database driver ? -->
<!-- Feel free to include any other installation details that could be relevant to this report -->


## What is happening ?
<!-- If reporting an issue with the API, please include relevant logs by setting ARA_DEBUG to True and ARA_LOG_LEVEL to DEBUG -->
<!-- If reporting an exception from an Ansible role or plugin, please include the full error or exception trace by running ansible-playbook with "-vvv" -->


## What should be happening ?

